import { LiveTimeUpdater } from "../liveshift/LiveTimeUpdater";
import { AVPBase } from "./AVPBase";
import { OhosSaasPlayer } from "./nativeclass/OhosSaasPlayer";
import { UrlSource } from "./source/UrlSource";
import url from "@ohos.url";
import { prepared, started } from "../player/IPlayer";
const onTimeShiftUpdaterListenerMap = new WeakMap();
const liveOnPreparedListenerMap = new WeakMap();
const liveOnLoadingStatusListenerMap = new WeakMap();
const liveOnStateChangedListenerMap = new WeakMap();
export class ApsaraLiveShiftPlayer extends AVPBase {
    constructor(z8, a9) {
        super(z8, a9);
        this.status = -1;
        this.statusWhenSeek = -1;
        this.liveSeekToTime = -1;
        this.liveSeekOffset = -1;
        this.mLiveShiftSource = null;
        this.mLiveTimeUpdater = null;
        this.mOutOnTimeShiftUpdaterListener = null;
        this.mInnerOnTimeShiftUpdaterListener = new InnerTimeShiftUpdateListener(this);
        this.mOutLiveOnPreparedListener = null;
        this.mInnerLiveOnPreparedListener = new InnerLivePreparedListener(this);
        this.mOutLiveOnStateChangedListener = null;
        this.mInnerLiveOnStateChangedListener = new InnerLiveStateChangedListener(this);
        this.mOutLiveOnLoadingStatusListener = null;
        this.mInnerLiveOnLoadingStatusListener = new InnerLiveLoadingStatusListener(this);
        this.mOutLiveSeekLiveCompletionListener = null;
        onTimeShiftUpdaterListenerMap.set(this, this.mInnerOnTimeShiftUpdaterListener);
        liveOnPreparedListenerMap.set(this, this.mInnerLiveOnPreparedListener);
        liveOnLoadingStatusListenerMap.set(this, this.mInnerLiveOnLoadingStatusListener);
        liveOnStateChangedListenerMap.set(this, this.mInnerLiveOnStateChangedListener);
    }
    createAlivcMediaPlayer(x8) {
        let y8 = new OhosSaasPlayer(x8);
        return y8;
    }
    setLiveShiftDataSource(u8) {
        this.mLiveShiftSource = u8;
        let v8 = new UrlSource();
        v8.setUri(this.mLiveShiftSource.getUrl());
        let w8 = this.getCorePlayer();
        if (w8 instanceof OhosSaasPlayer) {
            w8.setUrlDataSource(v8);
        }
    }
    getCurrentLiveTime() {
        if (this.mLiveTimeUpdater) {
            return this.mLiveTimeUpdater.getLiveTime();
        }
        return 0;
    }
    getCurrentTime() {
        if (this.mLiveTimeUpdater) {
            return this.mLiveTimeUpdater.getPlayTime();
        }
        return 0;
    }
    seekToLiveTime(m8) {
        if (this.status == ApsaraLiveShiftPlayer.SeekLive) {
            return;
        }
        if (this.mLiveShiftSource == null) {
            return;
        }
        this.statusWhenSeek = this.status;
        this.status = ApsaraLiveShiftPlayer.SeekLive;
        this.liveSeekToTime = m8;
        this.liveSeekOffset = this.getCurrentLiveTime() - this.liveSeekToTime;
        if (this.liveSeekToTime < 0) {
            this.liveSeekToTime = 0;
            this.liveSeekToTime = this.getCurrentLiveTime();
        }
        let n8 = this.mLiveShiftSource?.getUrl();
        if (this.liveSeekToTime > 0 && this.liveSeekOffset > 0) {
            let o8 = url.URL.parseURL(n8);
            let p8 = new url.URLParams(o8.search);
            let q8 = p8.entries();
            let r8 = Array.from(q8);
            if (n8.endsWith("?") || n8.endsWith("&")) {
                n8 += ("lhs_offset_unix_s_0=" + this.liveSeekOffset + "&lhs_start=1&aliyunols=on");
            }
            else {
                if (r8.length <= 0) {
                    n8 += ("?lhs_offset_unix_s_0=" + this.liveSeekOffset + "&lhs_start=1&aliyunols=on");
                }
                else {
                    n8 += ("&lhs_offset_unix_s_0=" + this.liveSeekOffset + "&lhs_start=1&aliyunols=on");
                }
            }
            let s8 = new UrlSource();
            s8.setUri(n8);
            let t8 = this.getCorePlayer();
            if (t8 instanceof OhosSaasPlayer) {
                t8.setUrlDataSource(s8);
                t8.prepare();
            }
        }
    }
    start() {
        super.start();
        if (this.mLiveTimeUpdater != null) {
            this.mLiveTimeUpdater.resumeUpdater();
        }
    }
    pause() {
        super.pause();
        this.mLiveTimeUpdater?.pauseUpdater();
    }
    stop() {
        super.stop();
        this.mLiveTimeUpdater?.stopUpdater();
    }
    onUpdater(j8, k8, l8) {
        console.info(ApsaraLiveShiftPlayer.tag + `onUpdater, currentTime: ${j8}, shiftStartTime: ${k8}, shiftEndTime: ${l8}`);
        if (this.mOutOnTimeShiftUpdaterListener) {
            this.mOutOnTimeShiftUpdaterListener.onUpdater(j8, k8, l8);
        }
    }
    onPrepared() {
        console.info(ApsaraLiveShiftPlayer.tag + " onPrepared");
        if (this.mLiveTimeUpdater != null) {
            this.mLiveTimeUpdater.stopUpdater();
        }
        else {
            if (this.mLiveShiftSource) {
                this.mLiveTimeUpdater = new LiveTimeUpdater(this.mLiveShiftSource);
                this.mLiveTimeUpdater.setUpdaterListener(this.mInnerOnTimeShiftUpdaterListener);
            }
        }
        let i8 = this.getConfig();
        if (i8 != undefined) {
            this.mLiveTimeUpdater?.setConfig(i8);
            this.mLiveTimeUpdater?.setStartPlayTime(this.liveSeekToTime);
            this.mLiveTimeUpdater?.startUpdater();
        }
        if (this.status == ApsaraLiveShiftPlayer.SeekLive) {
            this.status = prepared;
            if (this.status == started) {
                this.start();
            }
            else {
                if (this.isAutoPlay()) {
                    this.mLiveTimeUpdater?.resumeUpdater();
                }
                else {
                    this.mLiveTimeUpdater?.pauseUpdater();
                }
            }
            if (this.mOutLiveSeekLiveCompletionListener != null) {
                console.info(ApsaraLiveShiftPlayer.tag + ` onSeekLiveCompletion, playTime: ${this.liveSeekToTime}`);
                this.mOutLiveSeekLiveCompletionListener.onSeekLiveCompletion(this.liveSeekToTime);
            }
            this.liveSeekToTime = -1;
        }
        else {
            this.status = prepared;
            if (this.mOutLiveOnPreparedListener != null) {
                this.mOutLiveOnPreparedListener.onPrepared();
            }
        }
    }
    onStateChanged(h8) {
        console.info(ApsaraLiveShiftPlayer.tag + " onStateChanged, newState: " + h8);
        if (h8 != prepared) {
            this.status = h8;
        }
        if (this.mOutLiveOnStateChangedListener != null) {
            this.mOutLiveOnStateChangedListener.onStateChanged(h8);
        }
    }
    onLoadingBegin() {
        console.info(ApsaraLiveShiftPlayer.tag + " onLoadingBegin");
        if (this.mLiveTimeUpdater != null) {
            this.mLiveTimeUpdater.pauseUpdater();
        }
        if (this.mOutLiveOnLoadingStatusListener != null) {
            this.mOutLiveOnLoadingStatusListener.onLoadingBegin();
        }
    }
    onLoadingProgress(f8, g8) {
        console.info(ApsaraLiveShiftPlayer.tag + " onLoadingProgress, percent: " + f8);
        if (this.mOutLiveOnLoadingStatusListener != null) {
            this.mOutLiveOnLoadingStatusListener.onLoadingProgress(f8, g8);
        }
    }
    onLoadingEnd() {
        console.info(ApsaraLiveShiftPlayer.tag + " onLoadingEnd");
        if (this.mLiveTimeUpdater != null) {
            this.mLiveTimeUpdater.resumeUpdater();
        }
        if (this.mOutLiveOnLoadingStatusListener != null) {
            this.mOutLiveOnLoadingStatusListener.onLoadingEnd();
        }
    }
    setOnTimeShiftUpdaterListener(e8) {
        this.mOutOnTimeShiftUpdaterListener = e8;
    }
    setOnSeekLiveCompletionListener(d8) {
        this.mOutLiveSeekLiveCompletionListener = d8;
    }
    setOnStateChangedListener(c8) {
        this.mOutLiveOnStateChangedListener = c8;
        super.setOnStateChangedListener(this.mInnerLiveOnStateChangedListener);
    }
    setOnPreparedListener(b8) {
        this.mOutLiveOnPreparedListener = b8;
        super.setOnPreparedListener(this.mInnerLiveOnPreparedListener);
    }
    setOnLoadingStatusListener(a8) {
        this.mOutLiveOnLoadingStatusListener = a8;
        super.setOnLoadingStatusListener(this.mInnerLiveOnLoadingStatusListener);
    }
}
ApsaraLiveShiftPlayer.tag = "ApsaraLiveShiftPlayer";
ApsaraLiveShiftPlayer.SeekLive = 10;
class InnerTimeShiftUpdateListener {
    constructor(z7) {
        this.avPlayerRef = z7;
    }
    onUpdater(w7, x7, y7) {
        console.log(`currentTime: ${w7}}, shiftStartTime: ${x7}, shiftEndTime: ${y7} `);
        if (this.avPlayerRef != null) {
            this.avPlayerRef.onUpdater(w7, x7, y7);
        }
    }
}
class InnerLivePreparedListener {
    constructor(v7) {
        this.avPlayerRef = v7;
    }
    onPrepared() {
        if (this.avPlayerRef != null) {
            this.avPlayerRef.onPrepared();
        }
    }
}
class InnerLiveStateChangedListener {
    constructor(u7) {
        this.avPlayerRef = u7;
    }
    onStateChanged(t7) {
        if (this.avPlayerRef != null) {
            this.avPlayerRef.onStateChanged(t7);
        }
    }
}
class InnerLiveLoadingStatusListener {
    constructor(s7) {
        this.avPlayerRef = s7;
    }
    onLoadingBegin() {
        if (this.avPlayerRef != null) {
            this.avPlayerRef.onLoadingBegin();
        }
    }
    onLoadingProgress(q7, r7) {
        if (this.avPlayerRef != null) {
            this.avPlayerRef.onLoadingProgress(q7, r7);
        }
    }
    onLoadingEnd() {
        if (this.avPlayerRef != null) {
            this.avPlayerRef.onLoadingEnd();
        }
    }
    ;
}
