import premierlibrary from 'libpremierlibrary.so';
import { Log } from '../../utils/Log';
import { Option, AudioStatus, } from '../IPlayer';
import { InfoBean } from '../bean/InfoBean';
import { findInfoCodeByValue, InfoCode } from '../bean/InfoCode';
import { findErrorCodeByValue } from '../bean/PlayerErrorCode';
import { ErrorInfo } from '../bean/ErrorInfo';
import { ObjCreateHelper } from '../../utils/ObjCreateHelper';
const log = new Log('NativePlayerBase');
export class NativePlayerBase {
    constructor(o25) {
        this.mNativeContext = 0;
        this.objHelper = new ObjCreateHelper();
        this.getNativeContext = () => {
            log.info(`getNativeContext, address: ${this.mNativeContext}`);
            return this.mNativeContext;
        };
        this.setNativeContext = (a29) => {
            log.info(`setNativeContext, address: ${a29}`);
            this.mNativeContext = a29;
        };
        this.getHelper = () => {
            log.info(`getHelper`);
            return this.objHelper;
        };
        this.getContext = () => {
            log.info(`getNativeContext, address: ${this.mNativeContext}`);
            return this.mContext;
        };
        this.onPrepared = () => {
            console.log('onPrepared called at nativePlayerBase.');
            if (this.mOnPreparedListener != null) {
                this.mOnPreparedListener.onPrepared();
            }
        };
        this.onCircleStart = () => {
            if (this.mOnInfoListener != null) {
                let z28 = new InfoBean();
                z28.setCode(InfoCode.LoopingStart);
                this.mOnInfoListener.onInfo(z28);
            }
        };
        this.onAutoPlayStart = () => {
            if (this.mOnInfoListener != null) {
                let y28 = new InfoBean();
                y28.setCode(InfoCode.AutoPlayStart);
                this.mOnInfoListener.onInfo(y28);
            }
        };
        this.onEvent = (u28, v28) => {
            if (this.mOnInfoListener != null) {
                let w28 = findInfoCodeByValue(u28);
                let x28 = new InfoBean();
                x28.setCode(w28);
                x28.setExtraMsg(v28);
                this.mOnInfoListener.onInfo(x28);
            }
        };
        this.onCurrentDownloadSpeed = (s28) => {
            if (this.mOnInfoListener != null) {
                let t28 = new InfoBean();
                t28.setCode(InfoCode.CurrentDownloadSpeed);
                t28.setExtraValue(s28);
                this.mOnInfoListener.onInfo(t28);
            }
        };
        this.onUtcTimeUpdate = (q28) => {
            if (this.mOnInfoListener != null) {
                let r28 = new InfoBean();
                r28.setCode(InfoCode.UtcTime);
                r28.setExtraValue(q28);
                this.mOnInfoListener.onInfo(r28);
            }
        };
        this.onLocalCacheLoad = (o28) => {
            if (this.mOnInfoListener != null) {
                let p28 = new InfoBean();
                p28.setCode(InfoCode.LocalCacheLoaded);
                p28.setExtraValue(o28);
                this.mOnInfoListener.onInfo(p28);
            }
        };
        this.onBufferedPositionUpdate = (m28) => {
            if (this.mOnInfoListener != null) {
                let n28 = new InfoBean();
                n28.setCode(InfoCode.BufferedPosition);
                n28.setExtraValue(m28);
                this.mOnInfoListener.onInfo(n28);
            }
        };
        this.onCurrentPositionUpdate = (k28) => {
            if (this.mOnInfoListener != null) {
                let l28 = new InfoBean();
                l28.setCode(InfoCode.CurrentPosition);
                l28.setExtraValue(k28);
                this.mOnInfoListener.onInfo(l28);
            }
        };
        this.onFirstFrameShow = () => {
            if (this.mOnRenderingStartListener != null) {
                this.mOnRenderingStartListener.onRenderingStart();
            }
        };
        this.onVideoSizeChanged = (i28, j28) => {
            if (this.mOnVideoSizeChangedListener != null) {
                this.mOnVideoSizeChangedListener.onVideoSizeChanged(i28, j28);
            }
        };
        this.onAudioInterruptEvent = (h28) => {
            if (this.mOnAudioInterruptEventListener != null) {
                if (h28 < AudioStatus.AUDIO_STATUS_DEFAULT || h28 > AudioStatus.AUDIO_STATUS_UNDUCK) {
                    log.info('onAudioInterruptEvent exception audioStatus: ' + h28);
                    this.mOnAudioInterruptEventListener.onAudioInterruptEvent(AudioStatus.AUDIO_STATUS_DEFAULT);
                    return;
                }
                this.mOnAudioInterruptEventListener.onAudioInterruptEvent(h28);
            }
        };
        this.onLoadingStart = () => {
            if (this.mOnLoadingStatusListener != null) {
                this.mOnLoadingStatusListener.onLoadingBegin();
            }
        };
        this.onLoadingProgress = (g28) => {
            if (this.mOnLoadingStatusListener != null) {
                this.mOnLoadingStatusListener.onLoadingProgress(g28, 0);
            }
        };
        this.onLoadingEnd = () => {
            if (this.mOnLoadingStatusListener != null) {
                this.mOnLoadingStatusListener.onLoadingEnd();
            }
        };
        this.onAVNotSyncStart = (f28) => {
            if (this.mOnAVNotSyncStatusListener != null) {
                this.mOnAVNotSyncStatusListener.onAVNotSyncStart(f28);
            }
        };
        this.onAVNotSyncEnd = (e28) => {
            if (this.mOnAVNotSyncStatusListener != null) {
                this.mOnAVNotSyncStatusListener.onAVNotSyncEnd();
            }
        };
        this.onSeekEnd = () => {
            if (this.mOnSeekCompleteListener != null) {
                this.mOnSeekCompleteListener.onSeekComplete();
            }
        };
        this.onStatusChanged = (c28, d28) => {
            log.info('onStatusChanged, newState: ' + c28 + ' oldState: ' + d28);
            if (this.mOnStateChangedListener != null) {
                this.mOnStateChangedListener.onStateChanged(c28);
            }
        };
        this.onCompletion = () => {
            if (this.mOnCompletionListener != null) {
                this.mOnCompletionListener.onCompletion();
            }
        };
        this.onVideoRendered = (a28, b28) => {
            if (this.mOnVideoRenderedListener != null) {
                this.mOnVideoRenderedListener.onVideoRendered(a28, b28);
            }
        };
        this.onShowSubtitle = (x27, y27, z27) => {
            if (this.mOnSubtitleDisplayListener != null) {
                this.mOnSubtitleDisplayListener.onSubtitleShow(x27, y27, z27);
            }
        };
        this.onSubtitleExtAdded = (v27, w27) => {
            if (this.mOnSubtitleDisplayListener != null) {
                this.mOnSubtitleDisplayListener.onSubtitleExtAdded(v27, w27);
            }
        };
        this.onHideSubtitle = (t27, u27) => {
            if (this.mOnSubtitleDisplayListener != null) {
                this.mOnSubtitleDisplayListener.onSubtitleHide(t27, u27);
            }
        };
        this.onSubtitleHeader = (r27, s27) => {
            if (this.mOnSubtitleDisplayListener != null) {
                this.mOnSubtitleDisplayListener.onSubtitleHeader(r27, s27);
            }
        };
        this.onError = (m27, n27, o27) => {
            let p27 = findErrorCodeByValue(m27);
            if (this.mOnErrorListener != null) {
                let q27 = new ErrorInfo();
                q27.setCode(p27);
                q27.setMsg(n27);
                q27.setExtra(o27);
                this.mOnErrorListener.onError(q27);
            }
        };
        this.onStreamSwitchSuc = (l27) => {
            if (this.mOnTrackChangedListener != null) {
                this.mOnTrackChangedListener.onChangedSuccess(l27);
            }
        };
        this.onStreamInfoGet = (k27) => {
            if (this.mOnTrackReadyListener != null) {
                this.mOnTrackReadyListener.onTrackReady(k27);
            }
        };
        this.onSubStreamInfoGet = (j27) => {
            if (this.mOnSubTrackReadyListener != null) {
                this.mOnSubTrackReadyListener.onSubTrackReady(j27);
            }
        };
        this.onSwitchStreamUrlResult = (e27, f27, g27) => {
            if (this.mOnStreamSwitchedListener == null) {
                return;
            }
            if (f27 == 0) {
                this.mOnStreamSwitchedListener.onSwitchedSuccess(e27);
            }
            else {
                let h27 = findErrorCodeByValue(f27);
                let i27 = new ErrorInfo();
                i27.setCode(h27);
                i27.setMsg(g27);
                this.mOnStreamSwitchedListener.onSwitchedFail(e27, i27);
            }
        };
        this.onCaptureScreen = (b27, c27, d27) => {
            if (this.mOnSnapShotListener != null) {
                this.mOnSnapShotListener.onSnapShot(d27, b27, c27);
            }
        };
        this.onSeiDataCallback = (z26, a27) => {
            if (this.mOnSeiDataListener != null) {
                this.mOnSeiDataListener.onSeiData(z26, new Uint8Array(a27));
            }
        };
        log.info('constructor_');
        this.mContext = o25;
        premierlibrary.nConstruct(this);
    }
    setOnPreparedListener(n25) {
        this.mOnPreparedListener = n25;
    }
    setOnInfoListener(m25) {
        this.mOnInfoListener = m25;
    }
    setOnRenderingStartListener(l25) {
        this.mOnRenderingStartListener = l25;
    }
    setOnStateChangedListener(k25) {
        this.mOnStateChangedListener = k25;
    }
    setOnCompletionListener(j25) {
        this.mOnCompletionListener = j25;
    }
    setOnLoadingStatusListener(i25) {
        this.mOnLoadingStatusListener = i25;
    }
    setOnErrorListener(h25) {
        this.mOnErrorListener = h25;
    }
    setOnVideoSizeChangedListener(g25) {
        this.mOnVideoSizeChangedListener = g25;
    }
    setOnSeekCompleteListener(f25) {
        this.mOnSeekCompleteListener = f25;
    }
    setOnSubtitleDisplayListener(e25) {
        this.mOnSubtitleDisplayListener = e25;
    }
    setOnVideoRenderedListener(d25) {
        this.mOnVideoRenderedListener = d25;
    }
    setOnAudioInterruptEventListener(c25) {
        this.mOnAudioInterruptEventListener = c25;
    }
    setOnTrackReadyListener(b25) {
        this.mOnTrackReadyListener = b25;
    }
    setOnSubTrackReadyListener(a25) {
        this.mOnSubTrackReadyListener = a25;
    }
    setOnStreamSwitchedListener(z24) {
        this.mOnStreamSwitchedListener = z24;
    }
    setOnAVNotSyncStatusListener(y24) {
        this.mOnAVNotSyncStatusListener = y24;
    }
    setOnTrackChangedListener(x24) {
        this.mOnTrackChangedListener = x24;
    }
    setOnSnapShotListener(w24) {
        this.mOnSnapShotListener = w24;
    }
    setOnSeiDataListener(v24) {
        this.mOnSeiDataListener = v24;
    }
    start() {
        log.info('nStart');
        premierlibrary.nStart(this);
    }
    pause() {
        log.info('nPause');
        premierlibrary.nPause(this);
    }
    stop() {
        log.info('nStop');
        premierlibrary.nStop(this);
    }
    prepare() {
        log.info('nPrepare');
        premierlibrary.nPrepare(this);
    }
    setAutoPlay(u24) {
        log.info('nPrepare');
        premierlibrary.nSetAutoPlay(this, u24);
    }
    setSurfaceId(t24) {
        log.info('nSetSurfaceId');
        premierlibrary.nSetSurfaceId(this, t24);
    }
    setSpeed(s24) {
        log.info('setSpeed');
        premierlibrary.nSetSpeed(this, s24);
    }
    switchStream(r24) {
        log.info('switchStream');
        premierlibrary.nSwitchStream(this, r24);
    }
    setAlphaRenderMode(q24) {
        log.info('setAlphaRenderMode');
        premierlibrary.nSetAlphaRenderMode(this, q24);
    }
    getAlphaRenderMode() {
        log.info('getAlphaRenderMode');
        return premierlibrary.nGetAlphaRenderMode(this);
    }
    selectTrack(p24) {
        log.info('selectTrack');
        premierlibrary.nSelectTrack(this, p24);
    }
    getCurrentTrack(n24) {
        log.info('getCurrentTrack, type: ' + n24);
        let o24 = premierlibrary.nGetCurrentStreamInfo(this, n24);
        return o24;
    }
    addExtSubtitle(m24) {
        log.info(`addExtSubtitle`);
        premierlibrary.nAddExtSubtitle(this, m24);
    }
    selectExtSubtitle(k24, l24) {
        log.info(`selectExtSubtitle`);
        premierlibrary.nSelectExtSubtitle(this, k24, l24);
    }
    setVolume(j24) {
        log.info('setVolume');
        premierlibrary.nSetVolume(this, j24);
    }
    getVolume() {
        log.info('getVolume');
        return premierlibrary.nGetVolume(this);
    }
    seekTo(h24, i24) {
        log.info('seekTo');
        premierlibrary.nSeekTo(this, h24, i24);
    }
    setStartTime(f24, g24) {
        log.info('setStartTime');
        premierlibrary.nSetStartTime(this, f24, g24);
    }
    getDuration() {
        log.info('getDuration');
        return premierlibrary.nGetDuration(this);
    }
    getPlayedDuration() {
        log.info('getPlayedDuration');
        return premierlibrary.nGetPlayedDuration(this);
    }
    getCurrentPosition() {
        log.info('getCurrentPosition');
        return premierlibrary.nGetCurrentPosition(this);
    }
    getBufferedPosition() {
        log.info('getBufferedPosition');
        return premierlibrary.nGetBufferedPosition(this);
    }
    getPlayerStatus() {
        log.info('getPlayerStatus');
        return premierlibrary.nGetPlayerStatus(this);
    }
    setTraceId(e24) {
        log.info('setTraceId');
        premierlibrary.nSetTraceId(this, e24);
    }
    enableHardwareDecoder(d24) {
        log.info('enableHardwareDecoder');
        premierlibrary.nEnableHardwareDecoder(this, d24);
    }
    release() {
        log.info('release');
        premierlibrary.nRelease(this);
    }
    setMute(c24) {
        log.info('setMute');
        premierlibrary.nSetMute(this, c24);
    }
    isMuted() {
        log.info('isMuted');
        return premierlibrary.nIsMuted(this) === 1;
    }
    setScaleMode(b24) {
        log.info('setScaleMode');
        premierlibrary.nSetScaleMode(this, b24);
    }
    getScaleMode() {
        log.info('getScaleMode');
        return premierlibrary.nGetScaleMode(this);
    }
    setLoop(a24) {
        log.info('setLoop');
        premierlibrary.nSetLoop(this, a24);
    }
    isLoop() {
        log.info('isLoop');
        return premierlibrary.nIsLoop(this) === 1;
    }
    getVideoWidth() {
        log.info('getVideoWidth');
        return premierlibrary.nGetVideoWidth(this);
    }
    getVideoHeight() {
        log.info('getVideoHeight');
        return premierlibrary.nGetVideoHeight(this);
    }
    getVideoRotation() {
        log.info('getVideoRotation');
        return premierlibrary.nGetVideoRotation(this);
    }
    reload() {
        log.info('reload');
        premierlibrary.nReload(this);
    }
    setRotateMode(z23) {
        log.info('setRotateMode');
        premierlibrary.nSetRotateMode(this, z23);
    }
    getRotateMode() {
        log.info('getRotateMode');
        return premierlibrary.nGetRotateMode(this);
    }
    setMirrorMode(y23) {
        log.info('setMirrorMode');
        premierlibrary.nSetMirrorMode(this, y23);
    }
    getMirrorMode() {
        log.info('getMirrorMode');
        return premierlibrary.nGetMirrorMode(this);
    }
    setVideoBackgroundColor(x23) {
        log.info('setVideoBackgroundColor');
        premierlibrary.nSetVideoBackgroundColor(this, x23);
    }
    getSpeed() {
        log.info('getSpeed');
        return premierlibrary.nGetSpeed(this);
    }
    isAutoPlay() {
        log.info('isAutoPlay');
        return premierlibrary.nIsAutoPlay(this) === 1;
    }
    setConfig(w23) {
        log.info('setConfig');
        premierlibrary.nSetConfig(this, w23);
        this.mPlayerConfig = w23;
    }
    getConfig() {
        log.info('getConfig');
        let v23 = premierlibrary.nGetConfig(this);
        return v23;
    }
    setOption(t23, u23) {
        log.info('setOption');
        premierlibrary.nSetOption(this, t23, u23);
    }
    getOption(q23) {
        let r23 = premierlibrary.nGetOption(this, q23);
        if (q23 == Option.RenderFPS ||
            q23 == Option.DownloadBitrate ||
            q23 == Option.VideoBitrate ||
            q23 == Option.AudioBitrate) {
            let s23 = parseFloat(r23);
            return s23;
        }
        return r23;
    }
    setStreamDelay(o23, p23) {
        log.info('setStreamDelay');
        premierlibrary.nSetStreamDelay(this, o23, p23);
    }
    setMaxAccurateSeekDelta(n23) {
        log.info('setMaxAccurateSeekDelta');
        premierlibrary.nSetMaxAccurateSeekDelta(this, n23);
    }
    setCacheConfig(m23) {
        log.info('setCacheConfig');
        premierlibrary.nSetCacheConfig(this, m23);
    }
    setIPResolveType(l23) {
        log.info('setIPResolveType');
        premierlibrary.nSetIPResolveType(this, l23);
    }
    setFastStart(k23) {
        log.info('setFastStart');
        premierlibrary.nSetFastStart(this, k23);
    }
    snapShot() {
        log.info('snapShot');
        premierlibrary.nSnapShot(this);
    }
    clearScreen() {
        log.info('clearScreen');
        premierlibrary.nClearScreen(this);
    }
    getSdkVersion() {
        log.info('getSdkVersion');
        return premierlibrary.nGetSdkVersion();
    }
    getCacheFilePathByUrl(j23) {
        log.info('getCacheFilePathByUrl');
        return premierlibrary.nGetCacheFilePathByUrl(this, j23);
    }
    getCacheFilePathByVid(f23, g23, h23, i23) {
        log.info('getCacheFilePathByVid');
        return premierlibrary.nGetCacheFilePathByVid(this, f23, g23, h23, i23);
    }
    getPropertyString(e23) {
        log.info('getPropertyString');
        return premierlibrary.nGetPropertyString(this, e23);
    }
    setDefaultBandWidth(d23) {
        log.info('setDefaultBandWidth');
        premierlibrary.nSetDefaultBandWidth(this, d23);
    }
    sendCustomEvent(c23) {
        log.info('sendCustomEvent');
        premierlibrary.nSendCustomEvent(this, c23);
    }
    setVideoTag(b23) {
        log.info('setVideoTag');
        premierlibrary.nSetVideoTag(this, b23);
    }
    setUserData(a23) {
        log.info('setUserData');
        premierlibrary.nSetUserData(this, a23);
    }
    getUserData() {
        log.info('getUserData');
        return premierlibrary.nGetUserData(this);
    }
    getNativeContextAddr() {
        return this.mNativeContext;
    }
}
